Apply .clangformat to all repo source files
Change-Id: I7e79c6058f0303f9a98911e3b7dd2e8596079344
[ROCm/clr commit: 9e47fccc89]
이 커밋은 다음에 포함됨:
@@ -30,20 +30,20 @@ THE SOFTWARE.
|
||||
#include "hip/hip_runtime.h"
|
||||
#include "test_common.h"
|
||||
|
||||
int main( void ) {
|
||||
hipDeviceProp_t prop;
|
||||
int main(void) {
|
||||
hipDeviceProp_t prop;
|
||||
int dev;
|
||||
|
||||
hipGetDevice( &dev ) ;
|
||||
printf( "ID of current HIP device: %d\n", dev );
|
||||
hipGetDevice(&dev);
|
||||
printf("ID of current HIP device: %d\n", dev);
|
||||
|
||||
memset( &prop, 0, sizeof( hipDeviceProp_t ) );
|
||||
memset(&prop, 0, sizeof(hipDeviceProp_t));
|
||||
prop.major = 1;
|
||||
prop.minor = 3;
|
||||
hipChooseDevice( &dev, &prop );
|
||||
printf( "ID of hip device closest to revision 1.3: %d\n", dev );
|
||||
hipChooseDevice(&dev, &prop);
|
||||
printf("ID of hip device closest to revision 1.3: %d\n", dev);
|
||||
|
||||
hipSetDevice( dev );
|
||||
hipSetDevice(dev);
|
||||
|
||||
passed();
|
||||
}
|
||||
|
||||
새 이슈에서 참조
사용자 차단